@@ -66,128 +66,48 @@ class Pod(NamespacedResource):
               it failed and kill associated containers. Value must be a positive
               integer.
 
-            affinity (dict[str, Any]): nodeAffinity preferredDuringSchedulingIgnoredDuringExecution
-              preference matchExpressions key operator enum: DoesNotExist,
-              Exists, Gt, In, .... values matchFields key operator enum:
-              DoesNotExist, Exists, Gt, In, .... values weight
-              requiredDuringSchedulingIgnoredDuringExecution nodeSelectorTerms
-              matchExpressions key operator enum: DoesNotExist, Exists, Gt, In,
-              .... values matchFields key operator enum: DoesNotExist, Exists,
-              Gt, In, .... values podAffinity
-              preferredDuringSchedulingIgnoredDuringExecution podAffinityTerm
-              labelSelector matchExpressions key operator values matchLabels
-              matchLabelKeys mismatchLabelKeys namespaceSelector
-              matchExpressions key operator values matchLabels namespaces
-              topologyKey weight requiredDuringSchedulingIgnoredDuringExecution
-              labelSelector matchExpressions key operator values matchLabels
-              matchLabelKeys mismatchLabelKeys namespaceSelector
-              matchExpressions key operator values matchLabels namespaces
-              topologyKey podAntiAffinity
-              preferredDuringSchedulingIgnoredDuringExecution podAffinityTerm
-              labelSelector matchExpressions key operator values matchLabels
-              matchLabelKeys mismatchLabelKeys namespaceSelector
-              matchExpressions key operator values matchLabels namespaces
-              topologyKey weight requiredDuringSchedulingIgnoredDuringExecution
-              labelSelector matchExpressions key operator values matchLabels
-              matchLabelKeys mismatchLabelKeys namespaceSelector
-              matchExpressions key operator values matchLabels namespaces
-              topologyKey.
+            affinity (dict[str, Any]): Affinity is a group of affinity scheduling rules.
 
             automount_service_account_token (bool): AutomountServiceAccountToken indicates whether a service account token
               should be automatically mounted.
 
-            containers (list[Any]): args command env name value valueFrom configMapKeyRef key name
-              fieldRef apiVersion fieldPath fileKeyRef key optional path
-              volumeName resourceFieldRef containerName divisor resource
-              secretKeyRef key name envFrom configMapRef name prefix secretRef
-              name image imagePullPolicy enum: Always, IfNotPresent, Never
-              lifecycle postStart exec command httpGet host httpHeaders name
-              value path port scheme enum: HTTP, HTTPS sleep seconds tcpSocket
-              host port preStop exec command httpGet host httpHeaders name value
-              path port scheme enum: HTTP, HTTPS sleep seconds tcpSocket host
-              port stopSignal enum: SIGABRT, SIGALRM, SIGBUS, SIGCHLD, ....
-              livenessProbe exec command failureThreshold grpc port service
-              httpGet host httpHeaders name value path port scheme enum: HTTP,
-              HTTPS initialDelaySeconds periodSeconds successThreshold tcpSocket
-              host port terminationGracePeriodSeconds timeoutSeconds name ports
-              containerPort hostIP hostPort name protocol enum: SCTP, TCP, UDP
-              readinessProbe exec command failureThreshold grpc port service
-              httpGet host httpHeaders name value path port scheme enum: HTTP,
-              HTTPS initialDelaySeconds periodSeconds successThreshold tcpSocket
-              host port terminationGracePeriodSeconds timeoutSeconds
-              resizePolicy resourceName restartPolicy resources claims name
-              request limits requests restartPolicy restartPolicyRules action
-              exitCodes operator values securityContext allowPrivilegeEscalation
-              appArmorProfile localhostProfile type enum: Localhost,
-              RuntimeDefault, Unconfined capabilities add drop privileged
-              procMount enum: Default, Unmasked readOnlyRootFilesystem
-              runAsGroup runAsNonRoot runAsUser seLinuxOptions level role type
-              user seccompProfile localhostProfile type enum: Localhost,
-              RuntimeDefault, Unconfined windowsOptions gmsaCredentialSpec
-              gmsaCredentialSpecName hostProcess runAsUserName startupProbe exec
-              command failureThreshold grpc port service httpGet host
-              httpHeaders name value path port scheme enum: HTTP, HTTPS
-              initialDelaySeconds periodSeconds successThreshold tcpSocket host
-              port terminationGracePeriodSeconds timeoutSeconds stdin stdinOnce
-              terminationMessagePath terminationMessagePolicy enum:
-              FallbackToLogsOnError, File tty volumeDevices devicePath name
-              volumeMounts mountPath mountPropagation enum: Bidirectional,
-              HostToContainer, None name readOnly recursiveReadOnly subPath
-              subPathExpr workingDir.
+            containers (list[Any]): List of containers belonging to the pod. Containers cannot currently
+              be added or removed. There must be at least one container in a
+              Pod. Cannot be updated.
 
-            dns_config (dict[str, Any]): nameservers options name value searches.
+            dns_config (dict[str, Any]): PodDNSConfig defines the DNS parameters of a pod in addition to those
+              generated from DNSPolicy.
 
             dns_policy (str): Set DNS policy for the pod. Defaults to "ClusterFirst". Valid values
               are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or
               'None'. DNS parameters given in DNSConfig will be merged with the
               policy selected with DNSPolicy. To have DNS options set along with
               hostNetwork, you have to specify DNS policy explicitly to
-              'ClusterFirstWithHostNet'.
+              'ClusterFirstWithHostNet'.  Possible enum values:  -
+              `"ClusterFirst"` indicates that the pod should use cluster DNS
+              first unless hostNetwork is true, if it is available, then fall
+              back on the default (as determined by kubelet) DNS settings.  -
+              `"ClusterFirstWithHostNet"` indicates that the pod should use
+              cluster DNS first, if it is available, then fall back on the
+              default (as determined by kubelet) DNS settings.  - `"Default"`
+              indicates that the pod should use the default (as determined by
+              kubelet) DNS settings.  - `"None"` indicates that the pod should
+              use empty DNS settings. DNS parameters such as nameservers and
+              search paths should be defined via DNSConfig.
 
             enable_service_links (bool): EnableServiceLinks indicates whether information about services should
               be injected into pod's environment variables, matching the syntax
               of Docker links. Optional: Defaults to true.
 
-            ephemeral_containers (list[Any]): args command env name value valueFrom configMapKeyRef key name
-              fieldRef apiVersion fieldPath fileKeyRef key optional path
-              volumeName resourceFieldRef containerName divisor resource
-              secretKeyRef key name envFrom configMapRef name prefix secretRef
-              name image imagePullPolicy enum: Always, IfNotPresent, Never
-              lifecycle postStart exec command httpGet host httpHeaders name
-              value path port scheme enum: HTTP, HTTPS sleep seconds tcpSocket
-              host port preStop exec command httpGet host httpHeaders name value
-              path port scheme enum: HTTP, HTTPS sleep seconds tcpSocket host
-              port stopSignal enum: SIGABRT, SIGALRM, SIGBUS, SIGCHLD, ....
-              livenessProbe exec command failureThreshold grpc port service
-              httpGet host httpHeaders name value path port scheme enum: HTTP,
-              HTTPS initialDelaySeconds periodSeconds successThreshold tcpSocket
-              host port terminationGracePeriodSeconds timeoutSeconds name ports
-              containerPort hostIP hostPort name protocol enum: SCTP, TCP, UDP
-              readinessProbe exec command failureThreshold grpc port service
-              httpGet host httpHeaders name value path port scheme enum: HTTP,
-              HTTPS initialDelaySeconds periodSeconds successThreshold tcpSocket
-              host port terminationGracePeriodSeconds timeoutSeconds
-              resizePolicy resourceName restartPolicy resources claims name
-              request limits requests restartPolicy restartPolicyRules action
-              exitCodes operator values securityContext allowPrivilegeEscalation
-              appArmorProfile localhostProfile type enum: Localhost,
-              RuntimeDefault, Unconfined capabilities add drop privileged
-              procMount enum: Default, Unmasked readOnlyRootFilesystem
-              runAsGroup runAsNonRoot runAsUser seLinuxOptions level role type
-              user seccompProfile localhostProfile type enum: Localhost,
-              RuntimeDefault, Unconfined windowsOptions gmsaCredentialSpec
-              gmsaCredentialSpecName hostProcess runAsUserName startupProbe exec
-              command failureThreshold grpc port service httpGet host
-              httpHeaders name value path port scheme enum: HTTP, HTTPS
-              initialDelaySeconds periodSeconds successThreshold tcpSocket host
-              port terminationGracePeriodSeconds timeoutSeconds stdin stdinOnce
-              targetContainerName terminationMessagePath
-              terminationMessagePolicy enum: FallbackToLogsOnError, File tty
-              volumeDevices devicePath name volumeMounts mountPath
-              mountPropagation enum: Bidirectional, HostToContainer, None name
-              readOnly recursiveReadOnly subPath subPathExpr workingDir.
+            ephemeral_containers (list[Any]): List of ephemeral containers run in this pod. Ephemeral containers may
+              be run in an existing pod to perform user-initiated actions such
+              as debugging. This list cannot be specified when creating a pod,
+              and it cannot be modified by updating the pod spec. In order to
+              add an ephemeral container to an existing pod, use the pod's
+              ephemeralcontainers subresource.
 
-            host_aliases (list[Any]): hostnames ip.
+            host_aliases (list[Any]): HostAliases is an optional list of hosts and IPs that will be injected
+              into the pod's hosts file if specified.
 
             host_ipc (bool): Use the host's ipc namespace. Optional: Default to false.
 
@@ -219,53 +139,34 @@ class Pod(NamespacedResource):
               hostname and does not affect its DNS records. When this field is
               set to a non-empty string: - It takes precedence over the values
               set in `hostname` and `subdomain`. - The Pod's hostname will be
-              set to this value.
+              set to this value. - `setHostnameAsFQDN` must be nil or set to
+              false. - `hostNetwork` must be set to false.  This field must be a
+              valid DNS subdomain as defined in RFC 1123 and contain at most 64
+              characters. Requires the HostnameOverride feature gate to be
+              enabled.
 
             image_pull_secrets (list[Any]): ImagePullSecrets is an optional list of references to secrets in the
               same namespace to use for pulling any of the images used by this
               PodSpec. If specified, these secrets will be passed to individual
               puller implementations for them to use. More info:
               https://kubernetes.io/docs/concepts/containers/images#specifying-
-              imagepullsecrets-on-a-pod.
+              imagepullsecrets-on-a-pod
 
-            init_containers (list[Any]): args command env name value valueFrom configMapKeyRef key name
-              fieldRef apiVersion fieldPath fileKeyRef key optional path
-              volumeName resourceFieldRef containerName divisor resource
-              secretKeyRef key name envFrom configMapRef name prefix secretRef
-              name image imagePullPolicy enum: Always, IfNotPresent, Never
-              lifecycle postStart exec command httpGet host httpHeaders name
-              value path port scheme enum: HTTP, HTTPS sleep seconds tcpSocket
-              host port preStop exec command httpGet host httpHeaders name value
-              path port scheme enum: HTTP, HTTPS sleep seconds tcpSocket host
-              port stopSignal enum: SIGABRT, SIGALRM, SIGBUS, SIGCHLD, ....
-              livenessProbe exec command failureThreshold grpc port service
-              httpGet host httpHeaders name value path port scheme enum: HTTP,
-              HTTPS initialDelaySeconds periodSeconds successThreshold tcpSocket
-              host port terminationGracePeriodSeconds timeoutSeconds name ports
-              containerPort hostIP hostPort name protocol enum: SCTP, TCP, UDP
-              readinessProbe exec command failureThreshold grpc port service
-              httpGet host httpHeaders name value path port scheme enum: HTTP,
-              HTTPS initialDelaySeconds periodSeconds successThreshold tcpSocket
-              host port terminationGracePeriodSeconds timeoutSeconds
-              resizePolicy resourceName restartPolicy resources claims name
-              request limits requests restartPolicy restartPolicyRules action
-              exitCodes operator values securityContext allowPrivilegeEscalation
-              appArmorProfile localhostProfile type enum: Localhost,
-              RuntimeDefault, Unconfined capabilities add drop privileged
-              procMount enum: Default, Unmasked readOnlyRootFilesystem
-              runAsGroup runAsNonRoot runAsUser seLinuxOptions level role type
-              user seccompProfile localhostProfile type enum: Localhost,
-              RuntimeDefault, Unconfined windowsOptions gmsaCredentialSpec
-              gmsaCredentialSpecName hostProcess runAsUserName startupProbe exec
-              command failureThreshold grpc port service httpGet host
-              httpHeaders name value path port scheme enum: HTTP, HTTPS
-              initialDelaySeconds periodSeconds successThreshold tcpSocket host
-              port terminationGracePeriodSeconds timeoutSeconds stdin stdinOnce
-              terminationMessagePath terminationMessagePolicy enum:
-              FallbackToLogsOnError, File tty volumeDevices devicePath name
-              volumeMounts mountPath mountPropagation enum: Bidirectional,
-              HostToContainer, None name readOnly recursiveReadOnly subPath
-              subPathExpr workingDir.
+            init_containers (list[Any]): List of initialization containers belonging to the pod. Init
+              containers are executed in order prior to containers being
+              started. If any init container fails, the pod is considered to
+              have failed and is handled according to its restartPolicy. The
+              name for an init container or normal container must be unique
+              among all containers. Init containers may not have Lifecycle
+              actions, Readiness probes, Liveness probes, or Startup probes. The
+              resourceRequirements of an init container are taken into account
+              during scheduling by finding the highest request/limit for each
+              resource type, and then using the max of that value or the sum of
+              the normal containers. Limits are applied to init containers in a
+              similar fashion. Init containers cannot currently be added or
+              removed. Cannot be updated. More info:
+              https://kubernetes.io/docs/concepts/workloads/pods/init-
+              containers/
 
             node_name (str): NodeName indicates in which node this pod is scheduled. If empty, this
               pod is a candidate for scheduling by the scheduler defined in
@@ -274,38 +175,14 @@ class Pod(NamespacedResource):
               should not be used to express a desire for the pod to be scheduled
               on a specific node.
               https://kubernetes.io/docs/concepts/scheduling-eviction/assign-
-              pod-node/#nodename.
+              pod-node/#nodename
 
             node_selector (dict[str, Any]): NodeSelector is a selector which must be true for the pod to fit on a
               node. Selector which must match a node's labels for the pod to be
               scheduled on that node. More info:
-              https://kubernetes.io/docs/concepts/configuration/assign-pod-
-              node/.
+              https://kubernetes.io/docs/concepts/configuration/assign-pod-node/
 
-            os (dict[str, Any]): Specifies the OS of the containers in the pod. Some pod and container
-              fields are restricted if this is set. If the OS field is set to
-              linux, the following fields must be unset:
-              -securityContext.windowsOptions If the OS field is set to windows,
-              following fields must be unset: - spec.hostPID - spec.hostIPC -
-              spec.hostUsers - spec.resources -
-              spec.securityContext.appArmorProfile -
-              spec.securityContext.seLinuxOptions -
-              spec.securityContext.seccompProfile - spec.securityContext.fsGroup
-              - spec.securityContext.fsGroupChangePolicy -
-              spec.securityContext.sysctls - spec.shareProcessNamespace -
-              spec.securityContext.runAsUser - spec.securityContext.runAsGroup -
-              spec.securityContext.supplementalGroups -
-              spec.securityContext.supplementalGroupsPolicy -
-              spec.containers[*].securityContext.appArmorProfile -
-              spec.containers[*].securityContext.seLinuxOptions -
-              spec.containers[*].securityContext.seccompProfile -
-              spec.containers[*].securityContext.capabilities -
-              spec.containers[*].securityContext.readOnlyRootFilesystem -
-              spec.containers[*].securityContext.privileged -
-              spec.containers[*].securityContext.allowPrivilegeEscalation -
-              spec.containers[*].securityContext.procMount -
-              spec.containers[*].securityContext.runAsUser -
-              spec.containers[*].securityContext.runAsGroup.
+            os (dict[str, Any]): PodOS defines the OS parameters of a pod.
 
             overhead (dict[str, Any]): Overhead represents the resource overhead associated with running a
               pod for a given RuntimeClass. This field will be autopopulated at
@@ -317,11 +194,14 @@ class Pod(NamespacedResource):
               Overhead will be set to the value defined in the corresponding
               RuntimeClass, otherwise it will remain unset and treated as zero.
               More info: https://git.k8s.io/enhancements/keps/sig-node/688-pod-
-              overhead/README.md.
+              overhead/README.md
 
             preemption_policy (str): PreemptionPolicy is the Policy for preempting pods with lower
               priority. One of Never, PreemptLowerPriority. Defaults to
-              PreemptLowerPriority if unset.
+              PreemptLowerPriority if unset.  Possible enum values:  - `"Never"`
+              means that pod never preempts other pods with lower priority.  -
+              `"PreemptLowerPriority"` means that pod can preempt other pods
+              with lower priority.
 
             priority (int): The priority value. Various system components use this field to find
               the priority of the pod. When Priority Admission Controller is
@@ -336,25 +216,34 @@ class Pod(NamespacedResource):
               with that name. If not specified, the pod priority will be default
               or zero if there is no default.
 
-            readiness_gates (list[Any]): conditionType.
+            readiness_gates (list[Any]): If specified, all readiness gates will be evaluated for pod readiness.
+              A pod is ready when all its containers are ready AND all
+              conditions specified in the readiness gates have status equal to
+              "True" More info: https://git.k8s.io/enhancements/keps/sig-
+              network/580-pod-readiness-gates
 
-            resource_claims (list[Any]): name resourceClaimName resourceClaimTemplateName.
+            resource_claims (list[Any]): ResourceClaims defines which ResourceClaims must be allocated and
+              reserved before the Pod is allowed to start. The resources will be
+              made available to those containers which consume them by name.
+              This is an alpha field and requires enabling the
+              DynamicResourceAllocation feature gate.  This field is immutable.
 
-            resources (dict[str, Any]): claims name request limits requests.
+            resources (dict[str, Any]): ResourceRequirements describes the compute resource requirements.
 
             restart_policy (str): Restart policy for all containers within the pod. One of Always,
               OnFailure, Never. In some contexts, only a subset of those values
               may be permitted. Default to Always. More info:
               https://kubernetes.io/docs/concepts/workloads/pods/pod-
-              lifecycle/#restart-policy.
+              lifecycle/#restart-policy  Possible enum values:  - `"Always"`  -
+              `"Never"`  - `"OnFailure"`
 
             runtime_class_name (str): RuntimeClassName refers to a RuntimeClass object in the node.k8s.io
-              group, which should be used to run this pod. If no RuntimeClass
+              group, which should be used to run this pod.  If no RuntimeClass
               resource matches the named class, the pod will not be run. If
               unset or empty, the "legacy" RuntimeClass will be used, which is
               an implicit class with an empty definition that uses the default
               runtime handler. More info:
-              https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class.
+              https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class
 
             scheduler_name (str): If specified, the pod will be dispatched by specified scheduler. If
               not specified, the pod will be dispatched by default scheduler.
@@ -362,25 +251,21 @@ class Pod(NamespacedResource):
             scheduling_gates (list[Any]): SchedulingGates is an opaque list of values that if specified will
               block scheduling the pod. If schedulingGates is not empty, the pod
               will stay in the SchedulingGated state and the scheduler will not
-              attempt to schedule the pod. SchedulingGates can only be set at
+              attempt to schedule the pod.  SchedulingGates can only be set at
               pod creation time, and be removed only afterwards.
 
-            security_context (dict[str, Any]): appArmorProfile localhostProfile type enum: Localhost, RuntimeDefault,
-              Unconfined fsGroup fsGroupChangePolicy enum: Always,
-              OnRootMismatch runAsGroup runAsNonRoot runAsUser
-              seLinuxChangePolicy seLinuxOptions level role type user
-              seccompProfile localhostProfile type enum: Localhost,
-              RuntimeDefault, Unconfined supplementalGroups
-              supplementalGroupsPolicy enum: Merge, Strict sysctls name value
-              windowsOptions gmsaCredentialSpec gmsaCredentialSpecName
-              hostProcess runAsUserName.
+            security_context (dict[str, Any]): PodSecurityContext holds pod-level security attributes and common
+              container settings. Some fields are also present in
+              container.securityContext.  Field values of
+              container.securityContext take precedence over field values of
+              PodSecurityContext.
 
             service_account (str): DeprecatedServiceAccount is a deprecated alias for ServiceAccountName.
               Deprecated: Use serviceAccountName instead.
 
             service_account_name (str): ServiceAccountName is the name of the ServiceAccount to use to run
               this pod. More info: https://kubernetes.io/docs/tasks/configure-
-              pod-container/configure-service-account/.
+              pod-container/configure-service-account/
 
             set_hostname_as_fqdn (bool): If true the pod's hostname will be configured as the pod's FQDN,
               rather than the leaf name (the default). In Linux containers, this
@@ -398,7 +283,8 @@ class Pod(NamespacedResource):
               ShareProcessNamespace cannot both be set. Optional: Default to
               false.
 
-            subdomain (str): If specified, the fully qualified Pod hostname will be "...svc.". If
+            subdomain (str): If specified, the fully qualified Pod hostname will be
+              "<hostname>.<subdomain>.<pod namespace>.svc.<cluster domain>". If
               not specified, the pod will not have a domainname at all.
 
             termination_grace_period_seconds (int): Optional duration in seconds the pod needs to terminate gracefully.
@@ -411,59 +297,16 @@ class Pod(NamespacedResource):
               forcibly halted with a kill signal. Set this value longer than the
               expected cleanup time for your process. Defaults to 30 seconds.
 
-            tolerations (list[Any]): effect enum: NoExecute, NoSchedule, PreferNoSchedule key operator
-              enum: Equal, Exists tolerationSeconds value.
+            tolerations (list[Any]): If specified, the pod's tolerations.
 
-            topology_spread_constraints (list[Any]): labelSelector matchExpressions key operator values matchLabels
-              matchLabelKeys maxSkew minDomains nodeAffinityPolicy enum: Honor,
-              Ignore nodeTaintsPolicy enum: Honor, Ignore topologyKey
-              whenUnsatisfiable enum: DoNotSchedule, ScheduleAnyway.
+            topology_spread_constraints (list[Any]): TopologySpreadConstraints describes how a group of pods ought to
+              spread across topology domains. Scheduler will schedule pods in a
+              way which abides by the constraints. All topologySpreadConstraints
+              are ANDed.
 
-            volumes (list[Any]): awsElasticBlockStore fsType partition readOnly volumeID azureDisk
-              cachingMode enum: None, ReadOnly, ReadWrite diskName diskURI
-              fsType kind enum: Dedicated, Managed, Shared readOnly azureFile
-              readOnly secretName shareName cephfs monitors path readOnly
-              secretFile secretRef name user cinder fsType readOnly secretRef
-              name volumeID configMap defaultMode items key mode path name csi
-              driver fsType nodePublishSecretRef name readOnly volumeAttributes
-              downwardAPI defaultMode items fieldRef apiVersion fieldPath mode
-              path resourceFieldRef containerName divisor resource emptyDir
-              medium sizeLimit ephemeral volumeClaimTemplate metadata
-              annotations creationTimestamp deletionGracePeriodSeconds
-              deletionTimestamp finalizers generateName generation labels
-              managedFields apiVersion fieldsType fieldsV1 manager operation
-              subresource time name namespace ownerReferences apiVersion
-              blockOwnerDeletion controller kind name uid resourceVersion
-              selfLink uid spec accessModes dataSource apiGroup kind name
-              dataSourceRef apiGroup kind name namespace resources limits
-              requests selector matchExpressions key operator values matchLabels
-              storageClassName volumeAttributesClassName volumeMode enum: Block,
-              Filesystem volumeName fc fsType lun readOnly targetWWNs wwids
-              flexVolume driver fsType options readOnly secretRef name flocker
-              datasetName datasetUUID gcePersistentDisk fsType partition pdName
-              readOnly gitRepo directory repository revision glusterfs endpoints
-              path readOnly hostPath path type enum: "", BlockDevice,
-              CharDevice, Directory, .... image pullPolicy enum: Always,
-              IfNotPresent, Never reference iscsi chapAuthDiscovery
-              chapAuthSession fsType initiatorName iqn iscsiInterface lun
-              portals readOnly secretRef name targetPortal name nfs path
-              readOnly server persistentVolumeClaim claimName readOnly
-              photonPersistentDisk fsType pdID portworxVolume fsType readOnly
-              volumeID projected defaultMode sources clusterTrustBundle
-              labelSelector matchExpressions key operator values matchLabels
-              name path signerName configMap items key mode path name
-              downwardAPI items fieldRef apiVersion fieldPath mode path
-              resourceFieldRef containerName divisor resource podCertificate
-              certificateChainPath credentialBundlePath keyPath keyType
-              maxExpirationSeconds signerName secret items key mode path name
-              serviceAccountToken audience expirationSeconds path quobyte group
-              readOnly registry tenant user volume rbd fsType image keyring
-              monitors pool readOnly secretRef name user scaleIO fsType gateway
-              protectionDomain readOnly secretRef name sslEnabled storageMode
-              storagePool system volumeName secret defaultMode items key mode
-              path optional secretName storageos fsType readOnly secretRef name
-              volumeName volumeNamespace vsphereVolume fsType storagePolicyID
-              storagePolicyName volumePath.
+            volumes (list[Any]): List of volumes that can be mounted by containers belonging to the
+              pod. More info:
+              https://kubernetes.io/docs/concepts/storage/volumes
 
         """
         super().__init__(**kwargs)
