@@ -96,13 +96,13 @@ def test_parse_explain(tmp_path: Path) -> None:
         "Deployment",
         "ImageContentSourcePolicy",
         "Machine",
-        "NMState",
-        "OAuth",
-        "Pipeline",
         "Pod",
         "Secret",
+        "NMState",
         "ServiceMeshMember",
         "ServingRuntime",
+        "OAuth",
+        "Pipeline",
         "Ingress",
         "RouteAdvertisements",
     ]
@@ -146,7 +146,9 @@ def test_parse_explain(tmp_path: Path) -> None:
 
         # Create a concise failure message for pytest
         failed_kinds = [kind for kind, _ in failures]
-        failure_summary = f"{len(failures)} resource(s) failed: {','.join(failed_kinds)}"
+        failure_summary = f"{len(failures)} resource(s) failed: {', '.join(failed_kinds[:5])}"
+        if len(failed_kinds) > 5:
+            failure_summary += f" and {len(failed_kinds) - 5} more"
 
         # Fail the test with summary - detailed output is already printed above
         raise AssertionError(failure_summary)
