@@ -1,13 +1,11 @@
 """FakeResourceRegistry implementation for fake Kubernetes client"""
 
-import json
 import logging
 from collections import defaultdict
-from pathlib import Path
-from typing import Any, DefaultDict, Union
+from typing import Any
 
 from fake_kubernetes_client.resource_field import FakeResourceField
-
+from ocp_resources.utils.schema_validator import SchemaValidator
 
 logger = logging.getLogger(__name__)
 
@@ -17,8 +15,8 @@ class FakeResourceRegistry:
 
     def __init__(self) -> None:
         # Store by kind to allow searching across API groups
-        self.resources: DefaultDict[str, list[dict[str, Any]]] = defaultdict(list)
-        self._resource_mappings_cache: Union[dict[str, Any], None] = None
+        self.resources: defaultdict[str, list[dict[str, Any]]] = defaultdict(list)
+        self._resource_mappings_cache: dict[str, Any] | None = None
         self._builtin_resources: dict[tuple[str, str], dict[str, Any]] = {}
         self._additional_resources: dict[str, list[dict[str, Any]]] = {}
         self._load_resource_definitions()
@@ -37,36 +35,14 @@ class FakeResourceRegistry:
             return kind_lower + "s"
 
     def _get_resource_mappings(self) -> dict[str, Any]:
-        """Load and cache the resource mappings file (expensive operation - only done once)"""
+        """Load and cache the resource mappings file using SchemaValidator"""
         if self._resource_mappings_cache is None:
-            mappings_file = Path(__file__).parent / "__resources-mappings.json"
-
-            try:
-                # Load from local fake client directory
-                if not mappings_file.exists():
-                    logger.warning(f"Resource mappings file not found at {mappings_file}")
-                    self._resource_mappings_cache = {}
-                else:
-                    with open(mappings_file, "r", encoding="utf-8") as f:
-                        self._resource_mappings_cache = json.load(f)
-                        logger.debug(f"Successfully loaded {len(self._resource_mappings_cache)} resource mappings")
-
-            except FileNotFoundError as e:
-                logger.error(f"Resource mappings file not found: {e}")
-                self._resource_mappings_cache = {}
-            except json.JSONDecodeError as e:
-                logger.error(f"Failed to parse resource mappings JSON file: {e}")
-                logger.error(f"File: {mappings_file}, Line: {e.lineno}, Column: {e.colno}")
-                self._resource_mappings_cache = {}
-            except IOError as e:
-                logger.error(f"IO error while reading resource mappings file: {e}")
-                self._resource_mappings_cache = {}
-            except PermissionError as e:
-                logger.error(f"Permission denied while reading resource mappings file: {e}")
-                self._resource_mappings_cache = {}
-            except Exception as e:
-                # Still catch unexpected exceptions but log them
-                logger.exception(f"Unexpected error while loading resource mappings: {type(e).__name__}: {e}")
+            # Use SchemaValidator to load the mappings - single source of truth
+            if SchemaValidator.load_mappings_data():
+                self._resource_mappings_cache = SchemaValidator.get_mappings_data() or {}
+                logger.debug(f"Loaded {len(self._resource_mappings_cache)} resource mappings from SchemaValidator")
+            else:
+                logger.error("Failed to load resource mappings from SchemaValidator")
                 self._resource_mappings_cache = {}
 
         return self._resource_mappings_cache
@@ -231,7 +207,7 @@ class FakeResourceRegistry:
             self._builtin_resources[key] = resource_def
             self._additional_resources.setdefault(kind, []).append(resource_def)
 
-    def register_resources(self, resources: Union[dict[str, Any], list[dict[str, Any]]]) -> None:
+    def register_resources(self, resources: dict[str, Any] | list[dict[str, Any]]) -> None:
         """
         Register custom resources dynamically.
 
@@ -315,10 +291,10 @@ class FakeResourceRegistry:
 
     def search(
         self,
-        kind: Union[str, None] = None,
-        group: Union[str, None] = None,
-        api_version: Union[str, None] = None,
-        **kwargs: Any,
+        kind: str | None = None,
+        group: str | None = None,
+        api_version: str | None = None,
+        **_kwargs: Any,
     ) -> list[FakeResourceField]:
         """Search for resource definitions"""
         results = []
@@ -352,7 +328,7 @@ class FakeResourceRegistry:
         """Get all resource definitions for a kind"""
         return self.resources.get(kind, [])
 
-    def get_resource_definition(self, kind: str, api_version: str) -> Union[dict[str, Any], None]:
+    def get_resource_definition(self, kind: str, api_version: str) -> dict[str, Any] | None:
         """Get specific resource definition by kind and API version"""
         definitions = self.resources.get(kind, [])
 
@@ -375,9 +351,9 @@ class FakeResourceRegistry:
 
         return None
 
-    def get_resource_definition_by_plural(self, plural: str, api_version: str) -> Union[dict[str, Any], None]:
+    def get_resource_definition_by_plural(self, plural: str, api_version: str) -> dict[str, Any] | None:
         """Get resource definition by plural name and API version"""
-        for kind, definitions in self.resources.items():
+        for _kind, definitions in self.resources.items():
             for definition in definitions:
                 if definition.get("plural") == plural and (
                     definition["api_version"] == api_version or definition.get("group_version") == api_version
