@@ -1,5 +1,13 @@
 import pytest
 
+from ocp_resources.resource import get_client
+
+
+@pytest.fixture(scope="class")
+def fake_client():
+    """Fixture that provides a fake client for testing"""
+    return get_client(fake=True)
+
 
 def pytest_runtest_makereport(item, call):
     """
@@ -18,4 +26,4 @@ def pytest_runtest_setup(item):
     if "incremental" in item.keywords:
         previousfailed = getattr(item.parent, "_previousfailed", None)
         if previousfailed is not None:
-            pytest.xfail("previous test failed (%s)" % previousfailed.name)
+            pytest.xfail(f"previous test failed ({previousfailed.name})")
