@@ -1,18 +1,14 @@
 import pytest
-from fake_kubernetes_client import FakeDynamicClient
+
 from ocp_resources.api_server import APIServer
 
 
 @pytest.mark.incremental
 class TestAPIServer:
     @pytest.fixture(scope="class")
-    def client(self):
-        return FakeDynamicClient()
-
-    @pytest.fixture(scope="class")
-    def apiserver(self, client):
+    def apiserver(self, fake_client):
         return APIServer(
-            client=client,
+            client=fake_client,
             name="test-apiserver",
         )
 
